==> salso_0.1.2.tar.gz: salso/src/rustlib/dahl-salso.h <==
#include <stdarg.h>
#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>

void dahl_salso__expected_loss(int32_t n_partitions,
                               int32_t n_items,
                               int32_t *partition_ptr,
                               double *psm_ptr,
                               int32_t loss,
                               double *results_ptr);

void dahl_salso__minimize_by_enumeration(int32_t n_items,
                                         double *psm_ptr,
                                         int32_t loss,
                                         int32_t *results_label_ptr);

void dahl_salso__minimize_by_salso(int32_t n_items,
                                   double *psm_ptr,
                                   int32_t loss,
                                   int32_t max_size,
                                   int32_t max_scans,
                                   int32_t n_permutations,
                                   double seconds,
                                   int32_t parallel,
                                   int32_t *results_labels_ptr,
                                   double *results_expected_loss_ptr,
                                   int32_t *results_scans_ptr,
                                   int32_t *results_actual_n_permutations_ptr);

void dahl_salso__psm(int32_t n_partitions,
                     int32_t n_items,
                     int32_t parallel,
                     int32_t *partitions_ptr,
                     double *psm_ptr);

==> salso_0.1.9.tar.gz: salso/src/rustlib/dahl-salso.h <==
#include <stdarg.h>
#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>

void dahl_salso__expected_loss(int32_t n_partitions,
                               int32_t n_items,
                               int32_t *partition_ptr,
                               double *psm_ptr,
                               int32_t loss,
                               double *results_ptr);

void dahl_salso__minimize_by_enumeration(int32_t n_items,
                                         double *psm_ptr,
                                         int32_t loss,
                                         int32_t *results_label_ptr);

void dahl_salso__minimize_by_salso(int32_t n_items,
                                   double *psm_ptr,
                                   int32_t loss,
                                   int32_t max_size,
                                   int32_t max_scans,
                                   int32_t n_permutations,
                                   double probability_of_exploration,
                                   double seconds,
                                   int32_t parallel,
                                   int32_t *results_labels_ptr,
                                   double *results_expected_loss_ptr,
                                   int32_t *results_scans_ptr,
                                   int32_t *results_actual_n_permutations_ptr,
                                   const int32_t *seed_ptr);

void dahl_salso__psm(int32_t n_partitions,
                     int32_t n_items,
                     int32_t parallel,
                     int32_t *partitions_ptr,
                     double *psm_ptr);
